@@ -831,6 +831,275 @@ int main() {
       return EXIT_FAILURE;
     }
   }
+  // dont parse UTF-16 code units of emojis as int if low byte is ascii digit
+  {
+    const std::u16string emojis[] = {
+        u"ℹ", u"ℹ️", u"☸", u"☸️", u"☹", u"☹️", u"✳",  u"✳️",
+        u"✴", u"✴️", u"⤴", u"⤴️", u"⤵", u"⤵️", u"〰", u"〰️",
+    };
+    bool failed = false;
+    auto array_size = sizeof(emojis) / sizeof(emojis[0]);
+    for (size_t i = 0; i < array_size; i++) {
+      auto e = emojis[i];
+      int foo;
+      auto answer = fast_float::from_chars(e.data(), e.data() + e.size(), foo);
+      if (answer.ec == std::errc()) {
+        failed = true;
+        std::cerr << "Incorrectly parsed emoji #" << i << " as integer " << foo
+                  << "." << std::endl;
+      }
+    }
+
+    if (failed) {
+      return EXIT_FAILURE;
+    }
+  }
+  // dont parse UTF-32 code points of emojis as int if low byte is ascii digit
+  {
+    const std::u32string emojis[] = {
+        U"ℹ",
+        U"ℹ️",
+        U"☸",
+        U"☸️",
+        U"☹",
+        U"☹️",
+        U"✳",
+        U"✳️",
+        U"✴",
+        U"✴️",
+        U"⤴",
+        U"⤴️",
+        U"⤵",
+        U"⤵️",
+        U"〰",
+        U"〰️",
+        U"🈲",
+        U"🈳",
+        U"🈴",
+        U"🈵",
+        U"🈶",
+        U"🈷",
+        U"🈷️",
+        U"🈸",
+        U"🈹",
+        U"🌰",
+        U"🌱",
+        U"🌲",
+        U"🌳",
+        U"🌴",
+        U"🌵",
+        U"🌶",
+        U"🌶️",
+        U"🌷",
+        U"🌸",
+        U"🌹",
+        U"🐰",
+        U"🐱",
+        U"🐲",
+        U"🐳",
+        U"🐴",
+        U"🐵",
+        U"🐶",
+        U"🐷",
+        U"🐸",
+        U"🐹",
+        U"🔰",
+        U"🔱",
+        U"🔲",
+        U"🔳",
+        U"🔴",
+        U"🔵",
+        U"🔶",
+        U"🔷",
+        U"🔸",
+        U"🔹",
+        U"😰",
+        U"😱",
+        U"😲",
+        U"😳",
+        U"😴",
+        U"😵",
+        U"😵‍💫",
+        U"😶",
+        U"😶‍🌫",
+        U"😶‍🌫️",
+        U"😷",
+        U"😸",
+        U"😹",
+        U"🤰",
+        U"🤰🏻",
+        U"🤰🏼",
+        U"🤰🏽",
+        U"🤰🏾",
+        U"🤰🏿",
+        U"🤱",
+        U"🤱🏻",
+        U"🤱🏼",
+        U"🤱🏽",
+        U"🤱🏾",
+        U"🤱🏿",
+        U"🤲",
+        U"🤲🏻",
+        U"🤲🏼",
+        U"🤲🏽",
+        U"🤲🏾",
+        U"🤲🏿",
+        U"🤳",
+        U"🤳🏻",
+        U"🤳🏼",
+        U"🤳🏽",
+        U"🤳🏾",
+        U"🤳🏿",
+        U"🤴",
+        U"🤴🏻",
+        U"🤴🏼",
+        U"🤴🏽",
+        U"🤴🏾",
+        U"🤴🏿",
+        U"🤵",
+        U"🤵‍♀",
+        U"🤵‍♀️",
+        U"🤵‍♂",
+        U"🤵‍♂️",
+        U"🤵🏻",
+        U"🤵🏻‍♀",
+        U"🤵🏻‍♀️",
+        U"🤵🏻‍♂",
+        U"🤵🏻‍♂️",
+        U"🤵🏼",
+        U"🤵🏼‍♀",
+        U"🤵🏼‍♀️",
+        U"🤵🏼‍♂",
+        U"🤵🏼‍♂️",
+        U"🤵🏽",
+        U"🤵🏽‍♀",
+        U"🤵🏽‍♀️",
+        U"🤵🏽‍♂",
+        U"🤵🏽‍♂️",
+        U"🤵🏾",
+        U"🤵🏾‍♀",
+        U"🤵🏾‍♀️",
+        U"🤵🏾‍♂",
+        U"🤵🏾‍♂️",
+        U"🤵🏿",
+        U"🤵🏿‍♀",
+        U"🤵🏿‍♀️",
+        U"🤵🏿‍♂",
+        U"🤵🏿‍♂️",
+        U"🤶",
+        U"🤶🏻",
+        U"🤶🏼",
+        U"🤶🏽",
+        U"🤶🏾",
+        U"🤶🏿",
+        U"🤷",
+        U"🤷‍♀",
+        U"🤷‍♀️",
+        U"🤷‍♂",
+        U"🤷‍♂️",
+        U"🤷🏻",
+        U"🤷🏻‍♀",
+        U"🤷🏻‍♀️",
+        U"🤷🏻‍♂",
+        U"🤷🏻‍♂️",
+        U"🤷🏼",
+        U"🤷🏼‍♀",
+        U"🤷🏼‍♀️",
+        U"🤷🏼‍♂",
+        U"🤷🏼‍♂️",
+        U"🤷🏽",
+        U"🤷🏽‍♀",
+        U"🤷🏽‍♀️",
+        U"🤷🏽‍♂",
+        U"🤷🏽‍♂️",
+        U"🤷🏾",
+        U"🤷🏾‍♀",
+        U"🤷🏾‍♀️",
+        U"🤷🏾‍♂",
+        U"🤷🏾‍♂️",
+        U"🤷🏿",
+        U"🤷🏿‍♀",
+        U"🤷🏿‍♀️",
+        U"🤷🏿‍♂",
+        U"🤷🏿‍♂️",
+        U"🤸",
+        U"🤸‍♀",
+        U"🤸‍♀️",
+        U"🤸‍♂",
+        U"🤸‍♂️",
+        U"🤸🏻",
+        U"🤸🏻‍♀",
+        U"🤸🏻‍♀️",
+        U"🤸🏻‍♂",
+        U"🤸🏻‍♂️",
+        U"🤸🏼",
+        U"🤸🏼‍♀",
+        U"🤸🏼‍♀️",
+        U"🤸🏼‍♂",
+        U"🤸🏼‍♂️",
+        U"🤸🏽",
+        U"🤸🏽‍♀",
+        U"🤸🏽‍♀️",
+        U"🤸🏽‍♂",
+        U"🤸🏽‍♂️",
+        U"🤸🏾",
+        U"🤸🏾‍♀",
+        U"🤸🏾‍♀️",
+        U"🤸🏾‍♂",
+        U"🤸🏾‍♂️",
+        U"🤸🏿",
+        U"🤸🏿‍♀",
+        U"🤸🏿‍♀️",
+        U"🤸🏿‍♂",
+        U"🤸🏿‍♂️",
+        U"🤹",
+        U"🤹‍♀",
+        U"🤹‍♀️",
+        U"🤹‍♂",
+        U"🤹‍♂️",
+        U"🤹🏻",
+        U"🤹🏻‍♀",
+        U"🤹🏻‍♀️",
+        U"🤹🏻‍♂",
+        U"🤹🏻‍♂️",
+        U"🤹🏼",
+        U"🤹🏼‍♀",
+        U"🤹🏼‍♀️",
+        U"🤹🏼‍♂",
+        U"🤹🏼‍♂️",
+        U"🤹🏽",
+        U"🤹🏽‍♀",
+        U"🤹🏽‍♀️",
+        U"🤹🏽‍♂",
+        U"🤹🏽‍♂️",
+        U"🤹🏾",
+        U"🤹🏾‍♀",
+        U"🤹🏾‍♀️",
+        U"🤹🏾‍♂",
+        U"🤹🏾‍♂️",
+        U"🤹🏿",
+        U"🤹🏿‍♀",
+        U"🤹🏿‍♀️",
+        U"🤹🏿‍♂",
+        U"🤹🏿‍♂️",
+    };
+    bool failed = false;
+    auto array_size = sizeof(emojis) / sizeof(emojis[0]);
+    for (size_t i = 0; i < array_size; i++) {
+      auto e = emojis[i];
+      int foo;
+      auto answer = fast_float::from_chars(e.data(), e.data() + e.size(), foo);
+      if (answer.ec == std::errc()) {
+        failed = true;
+        std::cerr << "Incorrectly parsed emoji #" << i << " as integer " << foo
+                  << "." << std::endl;
+      }
+    }
+
+    if (failed) {
+      return EXIT_FAILURE;
+    }
+  }
 
   return EXIT_SUCCESS;
 }
@@ -842,4 +1111,4 @@ int main() {
   std::cerr << "The test requires C++17." << std::endl;
   return EXIT_SUCCESS;
 }
-#endif
\ No newline at end of file
+#endif
